Trait cranelift_entity::SparseMapValue [−][src]
pub trait SparseMapValue<K> {
fn key(&self) -> K;
}Expand description
Trait for extracting keys from values stored in a SparseMap.
All values stored in a SparseMap must keep track of their own key in the map and implement
this trait to provide access to the key.
Required methods
Implementors
impl<T> SparseMapValue<T> for T where
T: EntityRef, [src]
impl<T> SparseMapValue<T> for T where
T: EntityRef, [src]Any EntityRef can be used as a sparse map value representing itself.